langmuir
========

.. image:: https://travis-ci.com/sigvaldm/langmuir.svg?branch=master
    :target: https://travis-ci.com/sigvaldm/langmuir

.. image:: https://coveralls.io/repos/github/sigvaldm/langmuir/badge.svg?branch=master
    :target: https://coveralls.io/github/sigvaldm/langmuir?branch=master

.. image:: https://img.shields.io/pypi/pyversions/langmuir.svg
    :target: https://pypi.org/project/langmuir

Functions for work on Langmuir probe theory

Installation
------------
Install from PyPI using ``pip`` (preferred method)::

    pip install langmuir

Or download the GitHub repository https://github.com/sigvaldm/langmuir.git and run::

    python setup.py install

Usage
-----

Example::

    >>> from langmuir import *
    >>> f = lafr_func('Sphere')
    >>> f(1,25)
    21.895
